const effectClassName = "card-animation";
const animate = (from, to, durationSeconds, callbackFunction) => {
  let step = 0;
  let value = from;
  const timeIncrement = 5;
  const numSteps = durationSeconds * 1e3 / timeIncrement;
  const valueIncrement = (to - from) / numSteps;
  const interval = setInterval(frame, timeIncrement);
  function frame() {
    if (step >= numSteps) {
      clearInterval(interval);
    } else {
      callbackFunction(value);
      value += valueIncrement;
      step++;
    }
  }
  return interval;
};
const addAnimation = (card) => {
  let enterAnimationInterval;
  let leaveAnimationInterval;
  card.addEventListener("mousemove", function(e) {
    const rect = card.getBoundingClientRect();
    const x = e.clientX - rect.left;
    const y = e.clientY - rect.top;
    card.style.setProperty("--cursor-x", x + "px");
    card.style.setProperty("--cursor-y", y + "px");
  });
  card.addEventListener("mouseenter", function(e) {
    clearInterval(leaveAnimationInterval);
    enterAnimationInterval = animate(0, 1, 0.3, (value) => {
      card.style.setProperty("--bg-opacity", `${value}`);
    });
  });
  card.addEventListener("mouseleave", function(e) {
    clearInterval(enterAnimationInterval);
    leaveAnimationInterval = animate(1, 0, 0.3, (value) => {
      card.style.setProperty("--bg-opacity", `${value}`);
    });
  });
};
const addAnimationToCards = () => {
  const cards = document.getElementsByClassName(effectClassName);
  for (const card of cards) {
    addAnimation(card);
  }
};
window.onload = addAnimationToCards;
addAnimationToCards();
